==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeDocumentFragment.h <==
// class gnu.xml.libxmlj.dom.GnomeDocumentFragment

// class file dependencies
// @dep_class d373442face9a031 gnu_xml_libxmlj_dom_GnomeDocumentFragment
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDocumentFragment_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDocumentFragment_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$object	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vmethods	gnu_xml_libxmlj_dom_GnomeDocumentFragment;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_refs	gnu_xml_libxmlj_dom_GnomeDocumentFragment;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDocumentFragment;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDocumentFragment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDocumentFragment_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeDocumentFragment.h <==
// class gnu.xml.libxmlj.dom.GnomeDocumentFragment

// class file dependencies
// @dep_class d373442face9a031 gnu_xml_libxmlj_dom_GnomeDocumentFragment
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDocumentFragment_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDocumentFragment_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$object	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vmethods	gnu_xml_libxmlj_dom_GnomeDocumentFragment;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_refs	gnu_xml_libxmlj_dom_GnomeDocumentFragment;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDocumentFragment;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$vtype _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDocumentFragment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDocumentFragment$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDocumentFragment_H_ */
